@@ -14,8 +14,8 @@ import subprocess
 def test():
     print("gplfinance.test()")
 
-def make_subplot(df, *args, **kwargs):
-    subplot = {'df': df,
+def make_subplot(data, *args, **kwargs):
+    subplot = {'data': data,
             'cmd': []}
     subplot["attribute"] = collections.OrderedDict()
 
@@ -44,7 +44,7 @@ def multiplot(*args, **kwargs):
                 #print('set %s %s' %(k, v))
                 g.cmd('set %s %s' %(k, v))
         cmd = subplot["cmd"]
-        g.cmd('$Mydata << EOD\n%s\nEOD' %(subplot["df"].to_string()))
+        g.cmd('$Mydata << EOD\n%s\nEOD' %(subplot["data"]))
         c = 'plot '
         for cmd in subplot["cmd"]:
             c += '$Mydata %s, ' %(cmd)
@@ -54,13 +54,13 @@ def multiplot(*args, **kwargs):
         g.cmd('unset for [i=1:200] label i')
     g.reset()
 
-def plot(df, *args, **kwargs):
-    __gnuplot(df, "plot", *args, **kwargs)
+def plot(data, *args, **kwargs):
+    __gnuplot(data, "plot", *args, **kwargs)
 
-def splot(df, *args, **kwargs):
-    __gnuplot(df, "splot", *args, **kwargs)
+def splot(data, *args, **kwargs):
+    __gnuplot(data, "splot", *args, **kwargs)
 
-def __gnuplot(df, plot_cmd, *args, **kwargs):
+def __gnuplot(data, plot_cmd, *args, **kwargs):
     g = gnuplot.Gnuplot()
 
     # kwargs input:
@@ -75,7 +75,7 @@ def __gnuplot(df, plot_cmd, *args, **kwargs):
             #print('set %s %s' %(k, v))
             g.cmd('set %s %s' %(k, v))
 
-    g.cmd('$Mydata << EOD\n%s\nEOD' %(df.to_string()))
+    g.cmd('$Mydata << EOD\n%s\nEOD' %(data))
     c = plot_cmd
     for cmd in args:
         c += ' $Mydata %s,' %(cmd)
